@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from pybb import defaults
+from django.conf import settings
 
 __author__ = 'zeus'
 
@@ -13,8 +14,9 @@ def processor(request):
         'PYBB_MARKUP',
         'PYBB_DEFAULT_TITLE',
         'PYBB_ENABLE_ANONYMOUS_POST',
-        'PYBB_ATTACHMENT_ENABLE'
-        ):
+        'PYBB_ATTACHMENT_ENABLE',
+        'PYBB_AVATAR_WIDTH',
+        'PYBB_AVATAR_HEIGHT'
+    ):
         context[i] = getattr(defaults, i, None)
-    context['PYBB_AVATAR_DIMENSIONS'] = '%sx%s' % (defaults.PYBB_AVATAR_WIDTH, defaults.PYBB_AVATAR_WIDTH)
     return context
