@@ -5,7 +5,11 @@ function pybb_delete_post(url, post_id, confirm_text){
         type: 'POST',
         dataType: 'text',
         success: function (data, textStatus) {
-            $("#" + post_id).slideUp();
+            if (data.length > 0) {
+                window.location = data;
+            } else {
+                $("#" + post_id).slideUp();
+            }
         }
     };
     $.ajax(obj);
